==> react-d3-0.1.1.tgz: package/piechart.js <==
/** @jsx React.DOM */
var React = require('react');
var d3 = require('d3');
var _ = require('lodash');
var Chart = require('./common').Chart;


var Arc = React.createClass({displayName: 'Arc',

  getDefaultProps: function() {
    return {
      labelTextFill: "black",
      valueTextFill: "white"
    }
  },

  propTypes: {
    fill: React.PropTypes.string,
    d: React.PropTypes.string,
    startAngle: React.PropTypes.number,
    endAngle: React.PropTypes.number,
    innerRadius: React.PropTypes.number,
    outerRadius: React.PropTypes.number
  },

  render: function() {
    // transform={"translate(" + arc.centroid() + ")"}
    props = this.props;
    var arc = d3.svg.arc()
      .innerRadius(props.innerRadius)
      .outerRadius(props.outerRadius)
      .startAngle(props.startAngle)
      .endAngle(props.endAngle);
    var rotate = "rotate(" + (props.startAngle+props.endAngle)/2 * (180/Math.PI) + ")";
    var positions = arc.centroid();
    var radius = props.outerRadius;
    var dist   = radius + 35;
    var angle  = (props.startAngle + props.endAngle) / 2;
    var x      = dist * (1.2 * Math.sin(angle));
    var y      = -dist * Math.cos(angle);
    var t = "translate(" + x + "," + y + ")";
    return (
      React.createElement("g", {className: "arc-group"}, 
        React.createElement("path", {
          className: "arc", 
          d: arc(), 
          fill: props.fill}
        ), 
        React.createElement("line", {
          className: "arc-line", 
          x1: "0", 
          x2: "0", 
          y1: -radius - 2, 
          y2: -radius - 26, 
          stroke: "black", 
          transform: rotate, 
          style: {
            "fill": props.labelTextFill,
            "strokeWidth": 2,
          }}, 
        ">"
        ), 
        React.createElement("text", {
          className: "arc-label-text", 
          transform: t, 
          dy: ".35em", 
          style: {
            "textAnchor": "middle",
            "fill": props.labelTextFill,
            "shapeRendering": "crispEdges"
          }}, 
          this.props.label
        ), 
        React.createElement("text", {
          className: "arc-value-text", 
          transform: "translate(" + arc.centroid() + ")", 
          dy: ".35em", 
          style: {
            "shapeRendering": "crispEdges",
            "textAnchor": "middle",
            "fill": props.valueTextFill
          }}, 
          this.props.value + "%"
        )
      )
    );
  }
});

var DataSeries = React.createClass({displayName: 'DataSeries',

  propTypes: {
    transform: React.PropTypes.string,
    data: React.PropTypes.array,
    innerRadius: React.PropTypes.number,
    radius: React.PropTypes.number
  },

  getDefaultProps: function() {
    return {
      innerRadius: 0,
      data: [],
      color: d3.scale.category20c()
    }
  },

  render: function() {
    var props = this.props;

    var pie = d3.layout
      .pie()
      .sort(null);

    var arcData = pie(props.data);

    var color = this.props.color;

    var arcs = [];
    arcData.forEach(function(arc, i) {
      arcs.push(
        React.createElement(Arc, {
          startAngle: arc.startAngle, 
          endAngle: arc.endAngle, 
          outerRadius: props.radius, 
          innerRadius: props.innerRadius, 
          labelTextFill: props.labelTextFill, 
          valueTextFill: props.valueTextFill, 
          fill: color(i), 
          label: props.labels[i], 
          value: props.data[i], 
          key: i, 
          width: props.width}
        )
      )
    });
    return (
      React.createElement("g", {className: "pie-group", transform: this.props.transform}, arcs)
    );
  }
});

var PieChart = React.createClass({displayName: 'PieChart',

  getDefaultProps: function() {
    return {
      title: ''
    }
  },

  propTypes: {
    radius: React.PropTypes.number,
    cx: React.PropTypes.number,
    cy: React.PropTypes.number,
    labelTextFill: React.PropTypes.string,
    valueTextFill: React.PropTypes.string,
    color: React.PropTypes.func,
    title: React.PropTypes.string
  },

  render: function() {
    var props = this.props;
    var transform = "translate("
      + (this.props.cx || this.props.width/2) + ","
      + (this.props.cy || this.props.height/2) + ")";
    var data = _.pluck(this.props.data, 'value');
    var labels = _.pluck(this.props.data, 'label');
    return (
      React.createElement(Chart, {
        className: "pie-chart", 
        width: this.props.width, 
        height: this.props.height, 
        title: this.props.title
      }, 
        React.createElement(DataSeries, {
          labelTextFill: this.props.labelTextFill, 
          valueTextFill: this.props.valueTextFill, 
          labels: labels, 
          color: this.props.color, 
          transform: transform, 
          data: data, 
          width: this.props.width, 
          height: this.props.height, 
          radius: this.props.radius, 
          innerRadius: this.props.innerRadius}
        )
      )
    );
  }

});

exports.PieChart = PieChart;

==> react-d3-0.1.6.tgz: package/piechart.js <==
'use strict';

var React = require('react');
var d3 = require('d3');
var _ = require('lodash');
var Chart = require('./common').Chart;


var Arc = React.createClass({displayName: 'Arc',

  getDefaultProps: function() {
    return {
      labelTextFill: "black",
      valueTextFill: "white"
    };
  },

  propTypes: {
    fill: React.PropTypes.string,
    d: React.PropTypes.string,
    startAngle: React.PropTypes.number,
    endAngle: React.PropTypes.number,
    innerRadius: React.PropTypes.number,
    outerRadius: React.PropTypes.number
  },

  render: function() {
    // transform={"translate(" + arc.centroid() + ")"}
    var props = this.props;
    var arc = d3.svg.arc()
      .innerRadius(props.innerRadius)
      .outerRadius(props.outerRadius)
      .startAngle(props.startAngle)
      .endAngle(props.endAngle);
    var rotate = "rotate(" + (props.startAngle+props.endAngle)/2 * (180/Math.PI) + ")";
    var positions = arc.centroid();
    var radius = props.outerRadius;
    var dist   = radius + 35;
    var angle  = (props.startAngle + props.endAngle) / 2;
    var x      = dist * (1.2 * Math.sin(angle));
    var y      = -dist * Math.cos(angle);
    var t = "translate(" + x + "," + y + ")";
    return (
      React.createElement("g", {className: "arc-group"}, 
        React.createElement("path", {
          className: "arc", 
          d: arc(), 
          fill: props.fill}
        ), 
        React.createElement("line", {
          className: "arc-line", 
          x1: "0", 
          x2: "0", 
          y1: -radius - 2, 
          y2: -radius - 26, 
          stroke: "black", 
          transform: rotate, 
          style: {
            "fill": props.labelTextFill,
            "strokeWidth": 2,
          }}, 
        ">"
        ), 
        React.createElement("text", {
          className: "arc-label-text", 
          transform: t, 
          dy: ".35em", 
          style: {
            "textAnchor": "middle",
            "fill": props.labelTextFill,
            "shapeRendering": "crispEdges"
          }}, 
          this.props.label
        ), 
        React.createElement("text", {
          className: "arc-value-text", 
          transform: "translate(" + arc.centroid() + ")", 
          dy: ".35em", 
          style: {
            "shapeRendering": "crispEdges",
            "textAnchor": "middle",
            "fill": props.valueTextFill
          }}, 
          this.props.value + "%"
        )
      )
    );
  }
});

var DataSeries = React.createClass({displayName: 'DataSeries',

  propTypes: {
    transform: React.PropTypes.string,
    data: React.PropTypes.array,
    innerRadius: React.PropTypes.number,
    radius: React.PropTypes.number
  },

  getDefaultProps: function() {
    return {
      innerRadius: 0,
      data: [],
      color: d3.scale.category20c()
    };
  },

  render: function() {
    var props = this.props;

    var pie = d3.layout
      .pie()
      .sort(null);

    var arcData = pie(props.data);

    var color = this.props.color;

    var arcs = [];
    arcData.forEach(function(arc, i) {
      arcs.push(
        React.createElement(Arc, {
          startAngle: arc.startAngle, 
          endAngle: arc.endAngle, 
          outerRadius: props.radius, 
          innerRadius: props.innerRadius, 
          labelTextFill: props.labelTextFill, 
          valueTextFill: props.valueTextFill, 
          fill: color(i), 
          label: props.labels[i], 
          value: props.data[i], 
          key: i, 
          width: props.width}
        )
      );
    });
    return (
      React.createElement("g", {className: "pie-group", transform: this.props.transform}, arcs)
    );
  }
});

var PieChart = React.createClass({displayName: 'PieChart',

  getDefaultProps: function() {
    return {
      title: ''
    };
  },

  propTypes: {
    radius: React.PropTypes.number,
    cx: React.PropTypes.number,
    cy: React.PropTypes.number,
    labelTextFill: React.PropTypes.string,
    valueTextFill: React.PropTypes.string,
    color: React.PropTypes.func,
    title: React.PropTypes.string
  },

  render: function() {
    var props = this.props;
    var transform = "translate(" +
      (this.props.cx || this.props.width/2) + "," +
      (this.props.cy || this.props.height/2) + ")";
    var data = _.pluck(this.props.data, 'value');
    var labels = _.pluck(this.props.data, 'label');
    return (
      React.createElement(Chart, {
        className: "pie-chart", 
        width: this.props.width, 
        height: this.props.height, 
        title: this.props.title
      }, 
        React.createElement(DataSeries, {
          labelTextFill: this.props.labelTextFill, 
          valueTextFill: this.props.valueTextFill, 
          labels: labels, 
          color: this.props.color, 
          transform: transform, 
          data: data, 
          width: this.props.width, 
          height: this.props.height, 
          radius: this.props.radius, 
          innerRadius: this.props.innerRadius}
        )
      )
    );
  }

});

exports.PieChart = PieChart;
